@@ -14,14 +14,16 @@
 
 #include <QListView>
 
-namespace KontactInterface {
+namespace KontactInterface
+{
 class Core;
 class Plugin;
 }
 
 class QAction;
 
-namespace Kontact {
+namespace Kontact
+{
 class Model;
 class MainWindow;
 class Navigator;
@@ -103,7 +105,7 @@ class IconSidePane : public SidePaneBase
 
 public:
     IconSidePane(KontactInterface::Core *core, QWidget *parent);
-    ~IconSidePane();
+    ~IconSidePane() override;
 
     void setCurrentPlugin(const QString &plugin) override;
 
