@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <ksettings/Dialog>
 
-namespace Kontact {
+namespace Kontact
+{
 class KontactConfigureDialog : public KSettings::Dialog
 {
     Q_OBJECT
